#[repr(transparent)]pub struct GroupingListGroup {
inner: TypedObjectRef<GroupingListGroup, ()>,
phantom: PhantomData<()>,
}Expand description
A group of items in a GroupingListModel.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<GroupingListGroup, ()>phantom: PhantomData<()>Implementations
Sourceimpl GroupingListGroup
impl GroupingListGroup
Sourcepub fn start(&self) -> <PhantomData<u32> as Property>::Value
pub fn start(&self) -> <PhantomData<u32> as Property>::Value
The position of the first item in this group.
Sourcepub fn end(&self) -> <PhantomData<u32> as Property>::Value
pub fn end(&self) -> <PhantomData<u32> as Property>::Value
The position of the last item in this group.
Sourcepub fn connect_model_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_model_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the model property
Sourcepub fn connect_start_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_start_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the start property
Sourcepub fn connect_end_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_end_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the end property
Sourcepub fn notify_model(&self)
pub fn notify_model(&self)
Notify listeners of a change in the model property
Sourcepub fn notify_start(&self)
pub fn notify_start(&self)
Notify listeners of a change in the start property
Sourcepub fn notify_end(&self)
pub fn notify_end(&self)
Notify listeners of a change in the end property
Sourceimpl GroupingListGroup
impl GroupingListGroup
Sourcepub fn new(model: &ListModel, range: RangeInclusive<u32>) -> Self
pub fn new(model: &ListModel, range: RangeInclusive<u32>) -> Self
Construct a new GroupingListGroup for the given model and range.
Sourcepub(super) fn contains(&self, position: u32) -> bool
pub(super) fn contains(&self, position: u32) -> bool
Whether this group contains the given position.
Sourcepub(super) fn handle_removal(&self, position: u32, removed: u32)
pub(super) fn handle_removal(&self, position: u32, removed: u32)
Handle the given removal of items that might affect this group.
This function panics if there would be no items left in this group.
Sourcepub(super) fn handle_addition(&self, position: u32, added: u32)
pub(super) fn handle_addition(&self, position: u32, added: u32)
Handle the given addition of items that might affect this group.
Sourcepub(super) fn add(&self, position: u32, added: u32)
pub(super) fn add(&self, position: u32, added: u32)
Add items to this list item.
This function assumes that the new items are contiguous to the current ones.
Sourcepub(super) fn process_batch(&self)
pub(super) fn process_batch(&self)
Process the accumulated batch of changes.
Sourcepub(super) fn drop_batch(&self)
pub(super) fn drop_batch(&self)
Drop the accumulated batch of changes.